@@ -20,6 +20,7 @@ from .auth import OutbrainAmplifyAuthenticator
 DEFAULT_END_DATE = pendulum.now()
 DEFAULT_GEO_LOCATION_BREAKDOWN = "region"
 DEFAULT_REPORT_GRANULARITY = "daily"
+DEFAULT_REPORT_CONVERSION_COUNT_BY_CLICK_DATE = "conversion_time"
 
 
 # Basic full refresh stream
@@ -61,6 +62,15 @@ class OutbrainAmplifyStream(HttpStream, ABC):
             raise ValueError(f"Specified start date: {start_date} is later than the end date: {end_date}")
         return start_date, end_date
 
+    @staticmethod
+    def _get_bool_conversion_count_by_click_date(value: str) -> str:
+        if value.lower() == "click/view_time":
+            return "true"
+        elif value.lower() == "conversion_time":
+            return "false"
+        else:
+            raise ValueError(f"Invalid value for conversion count by click date: {value}")
+
 
 class Marketers(OutbrainAmplifyStream):
     primary_key = "id"
@@ -401,6 +411,9 @@ class PerformanceReportCampaignsByMarketers(OutbrainAmplifyStream, HttpSubStream
         self, stream_state: Mapping[str, Any] = None, stream_slice: Mapping[str, Any] = None, next_page_token: Mapping[str, Any] = None
     ) -> str:
         stream_start, stream_end = self._get_time_interval(self.config.get("start_date"), self.config.get("end_date"))
+        stream_conversion_count = self._get_bool_conversion_count_by_click_date(
+            self.config.get("conversion_count", DEFAULT_REPORT_CONVERSION_COUNT_BY_CLICK_DATE)
+        )
         return (
             f"reports/marketers/{stream_slice['marketer_id']}/campaigns?from="
             + str(stream_start.date())
@@ -408,6 +421,8 @@ class PerformanceReportCampaignsByMarketers(OutbrainAmplifyStream, HttpSubStream
             + str(stream_end.date())
             + "&limit=500"
             + "&includeVideoStats=true"
+            + "&conversionsByClickDate="
+            + str(stream_conversion_count)
         )
 
 
@@ -461,6 +476,9 @@ class PerformanceReportPeriodicByMarketers(OutbrainAmplifyStream, HttpSubStream)
         self, stream_state: Mapping[str, Any] = None, stream_slice: Mapping[str, Any] = None, next_page_token: Mapping[str, Any] = None
     ) -> str:
         stream_start, stream_end = self._get_time_interval(self.config.get("start_date"), self.config.get("end_date"))
+        stream_conversion_count = self._get_bool_conversion_count_by_click_date(
+            self.config.get("conversion_count", DEFAULT_REPORT_CONVERSION_COUNT_BY_CLICK_DATE)
+        )
         return (
             f"reports/marketers/{stream_slice['marketer_id']}/periodic?from="
             + str(stream_start.date())
@@ -470,6 +488,8 @@ class PerformanceReportPeriodicByMarketers(OutbrainAmplifyStream, HttpSubStream)
             + str(self.config.get("report_granularity", DEFAULT_REPORT_GRANULARITY))
             + "&limit=500"
             + "&includeVideoStats=true"
+            + "&conversionsByClickDate="
+            + str(stream_conversion_count)
         )
 
 
@@ -525,6 +545,9 @@ class PerformanceReportPeriodicByMarketersCampaign(OutbrainAmplifyStream, HttpSu
         self, stream_state: Mapping[str, Any] = None, stream_slice: Mapping[str, Any] = None, next_page_token: Mapping[str, Any] = None
     ) -> str:
         stream_start, stream_end = self._get_time_interval(self.config.get("start_date"), self.config.get("end_date"))
+        stream_conversion_count = self._get_bool_conversion_count_by_click_date(
+            self.config.get("conversion_count", DEFAULT_REPORT_CONVERSION_COUNT_BY_CLICK_DATE)
+        )
         return (
             f"reports/marketers/{stream_slice['marketer_id']}/campaigns/periodic?from="
             + str(stream_start.date())
@@ -534,6 +557,8 @@ class PerformanceReportPeriodicByMarketersCampaign(OutbrainAmplifyStream, HttpSu
             + str(self.config.get("report_granularity", DEFAULT_REPORT_GRANULARITY))
             + "&limit=500"
             + "&includeVideoStats=true"
+            + "&conversionsByClickDate="
+            + str(stream_conversion_count)
         )
 
 
@@ -594,6 +619,9 @@ class PerformanceReportPeriodicContentByPromotedLinksCampaign(OutbrainAmplifyStr
         self, stream_state: Mapping[str, Any] = None, stream_slice: Mapping[str, Any] = None, next_page_token: Mapping[str, Any] = None
     ) -> str:
         stream_start, stream_end = self._get_time_interval(self.config.get("start_date"), self.config.get("end_date"))
+        stream_conversion_count = self._get_bool_conversion_count_by_click_date(
+            self.config.get("conversion_count", DEFAULT_REPORT_CONVERSION_COUNT_BY_CLICK_DATE)
+        )
         return (
             f"reports/marketers/{stream_slice['marketer_id']}/campaigns/{stream_slice['campaign_id']}/periodicContent?from="
             + str(stream_start.date())
@@ -603,6 +631,8 @@ class PerformanceReportPeriodicContentByPromotedLinksCampaign(OutbrainAmplifyStr
             + str(self.config.get("report_granularity", DEFAULT_REPORT_GRANULARITY))
             + "&limit=500"
             + "&includeVideoStats=true"
+            + "&conversionsByClickDate="
+            + str(stream_conversion_count)
         )
 
 
@@ -656,6 +686,9 @@ class PerformanceReportMarketersByPublisher(OutbrainAmplifyStream, HttpSubStream
         self, stream_state: Mapping[str, Any] = None, stream_slice: Mapping[str, Any] = None, next_page_token: Mapping[str, Any] = None
     ) -> str:
         stream_start, stream_end = self._get_time_interval(self.config.get("start_date"), self.config.get("end_date"))
+        stream_conversion_count = self._get_bool_conversion_count_by_click_date(
+            self.config.get("conversion_count", DEFAULT_REPORT_CONVERSION_COUNT_BY_CLICK_DATE)
+        )
         return (
             f"reports/marketers/{stream_slice['marketer_id']}/publishers?from="
             + str(stream_start.date())
@@ -663,6 +696,8 @@ class PerformanceReportMarketersByPublisher(OutbrainAmplifyStream, HttpSubStream
             + str(stream_end.date())
             + "&limit=500"
             + "&includeVideoStats=true"
+            + "&conversionsByClickDate="
+            + str(stream_conversion_count)
         )
 
 
@@ -718,6 +753,9 @@ class PerformanceReportPublishersByCampaigns(OutbrainAmplifyStream, HttpSubStrea
         self, stream_state: Mapping[str, Any] = None, stream_slice: Mapping[str, Any] = None, next_page_token: Mapping[str, Any] = None
     ) -> str:
         stream_start, stream_end = self._get_time_interval(self.config.get("start_date"), self.config.get("end_date"))
+        stream_conversion_count = self._get_bool_conversion_count_by_click_date(
+            self.config.get("conversion_count", DEFAULT_REPORT_CONVERSION_COUNT_BY_CLICK_DATE)
+        )
         return (
             f"reports/marketers/{stream_slice['marketer_id']}/campaigns/publishers?from="
             + str(stream_start.date())
@@ -725,6 +763,8 @@ class PerformanceReportPublishersByCampaigns(OutbrainAmplifyStream, HttpSubStrea
             + str(stream_end.date())
             + "&limit=500"
             + "&includeVideoStats=true"
+            + "&conversionsByClickDate="
+            + str(stream_conversion_count)
         )
 
 
@@ -778,6 +818,9 @@ class PerformanceReportMarketersByPlatforms(OutbrainAmplifyStream, HttpSubStream
         self, stream_state: Mapping[str, Any] = None, stream_slice: Mapping[str, Any] = None, next_page_token: Mapping[str, Any] = None
     ) -> str:
         stream_start, stream_end = self._get_time_interval(self.config.get("start_date"), self.config.get("end_date"))
+        stream_conversion_count = self._get_bool_conversion_count_by_click_date(
+            self.config.get("conversion_count", DEFAULT_REPORT_CONVERSION_COUNT_BY_CLICK_DATE)
+        )
         return (
             f"reports/marketers/{stream_slice['marketer_id']}/platforms?from="
             + str(stream_start.date())
@@ -785,6 +828,8 @@ class PerformanceReportMarketersByPlatforms(OutbrainAmplifyStream, HttpSubStream
             + str(stream_end.date())
             + "&limit=500"
             + "&includeVideoStats=true"
+            + "&conversionsByClickDate="
+            + str(stream_conversion_count)
         )
 
 
@@ -840,6 +885,9 @@ class PerformanceReportMarketersCampaignsByPlatforms(OutbrainAmplifyStream, Http
         self, stream_state: Mapping[str, Any] = None, stream_slice: Mapping[str, Any] = None, next_page_token: Mapping[str, Any] = None
     ) -> str:
         stream_start, stream_end = self._get_time_interval(self.config.get("start_date"), self.config.get("end_date"))
+        stream_conversion_count = self._get_bool_conversion_count_by_click_date(
+            self.config.get("conversion_count", DEFAULT_REPORT_CONVERSION_COUNT_BY_CLICK_DATE)
+        )
         return (
             f"reports/marketers/{stream_slice['marketer_id']}/campaigns/platforms?from="
             + str(stream_start.date())
@@ -847,6 +895,8 @@ class PerformanceReportMarketersCampaignsByPlatforms(OutbrainAmplifyStream, Http
             + str(stream_end.date())
             + "&limit=500"
             + "&includeVideoStats=true"
+            + "&conversionsByClickDate="
+            + str(stream_conversion_count)
         )
 
 
@@ -900,6 +950,9 @@ class PerformanceReportMarketersByGeoPerformance(OutbrainAmplifyStream, HttpSubS
         self, stream_state: Mapping[str, Any] = None, stream_slice: Mapping[str, Any] = None, next_page_token: Mapping[str, Any] = None
     ) -> str:
         stream_start, stream_end = self._get_time_interval(self.config.get("start_date"), self.config.get("end_date"))
+        stream_conversion_count = self._get_bool_conversion_count_by_click_date(
+            self.config.get("conversion_count", DEFAULT_REPORT_CONVERSION_COUNT_BY_CLICK_DATE)
+        )
         return (
             f"reports/marketers/{stream_slice['marketer_id']}/geo?from="
             + str(stream_start.date())
@@ -909,6 +962,8 @@ class PerformanceReportMarketersByGeoPerformance(OutbrainAmplifyStream, HttpSubS
             + str(self.config.get("geo_location_breakdown", DEFAULT_GEO_LOCATION_BREAKDOWN))
             + "&limit=500"
             + "&includeVideoStats=true"
+            + "&conversionsByClickDate="
+            + str(stream_conversion_count)
         )
 
 
@@ -964,6 +1019,9 @@ class PerformanceReportMarketersCampaignsByGeo(OutbrainAmplifyStream, HttpSubStr
         self, stream_state: Mapping[str, Any] = None, stream_slice: Mapping[str, Any] = None, next_page_token: Mapping[str, Any] = None
     ) -> str:
         stream_start, stream_end = self._get_time_interval(self.config.get("start_date"), self.config.get("end_date"))
+        stream_conversion_count = self._get_bool_conversion_count_by_click_date(
+            self.config.get("conversion_count", DEFAULT_REPORT_CONVERSION_COUNT_BY_CLICK_DATE)
+        )
         return (
             f"reports/marketers/{stream_slice['marketer_id']}/campaigns/geo?from="
             + str(stream_start.date())
@@ -973,6 +1031,8 @@ class PerformanceReportMarketersCampaignsByGeo(OutbrainAmplifyStream, HttpSubStr
             + str(self.config.get("geo_location_breakdown", DEFAULT_GEO_LOCATION_BREAKDOWN))
             + "&limit=500"
             + "&includeVideoStats=true"
+            + "&conversionsByClickDate="
+            + str(stream_conversion_count)
         )
 
 
@@ -1026,6 +1086,9 @@ class PerformanceReportMarketersByInterest(OutbrainAmplifyStream, HttpSubStream)
         self, stream_state: Mapping[str, Any] = None, stream_slice: Mapping[str, Any] = None, next_page_token: Mapping[str, Any] = None
     ) -> str:
         stream_start, stream_end = self._get_time_interval(self.config.get("start_date"), self.config.get("end_date"))
+        stream_conversion_count = self._get_bool_conversion_count_by_click_date(
+            self.config.get("conversion_count", DEFAULT_REPORT_CONVERSION_COUNT_BY_CLICK_DATE)
+        )
         return (
             f"reports/marketers/{stream_slice['marketer_id']}/interests?from="
             + str(stream_start.date())
@@ -1033,6 +1096,8 @@ class PerformanceReportMarketersByInterest(OutbrainAmplifyStream, HttpSubStream)
             + str(stream_end.date())
             + "&limit=500"
             + "&includeVideoStats=true"
+            + "&conversionsByClickDate="
+            + str(stream_conversion_count)
         )
 
 
